@@ -27,8 +27,8 @@ class Skus(str, Enum):
 
 def create_registry(
     registry_name: str = typer.Option(
-        "registry-" + str(random.randint(100_000_000, 999_999_999)),
-        help="The name of the registry",
+        "registry" + str(random.randint(100_000_000, 999_999_999)),
+        help="The name of the registry. Must conform to ^[a-zA-Z0-9]*$",
         prompt=True,
     ),
     resource_group_name: str = get_resource_group(),
